@@ -28,7 +28,7 @@ if __name__=='__main__':
             result = os.popen('sh fltk-config --cxxflags').readlines()
         else:
             result = os.popen('fltk-config --cxxflags').readlines()
-        print result
+        #print result
         if len(result) > 0:
             p_inc = map(lambda x: x.strip(), result[0].split(' '))
             for item in p_inc:
@@ -41,7 +41,7 @@ if __name__=='__main__':
     add_incl = string.join(include, ' ')
 
     # command line for swig-1.3.28 or later
-    cmd_line = "swig -w312 -w451 -w473 -I../swig %s -DFL_EXPORT -DPYTHON -module fltk -c++ -python -shadow -modern -dirprot -fastdispatch -o fltk_wrap.cpp ../swig/fltk.i "%add_incl
+    cmd_line = "swig -w312 -w451 -w473 -I../swig %s -DFL_EXPORT -DPYTHON -module fltk -c++ -python -shadow -modern -fastdispatch -o fltk_wrap.cpp ../swig/fltk.i "%add_incl
     # command line for swig-1.3.27
     # cmd_line = "swig -w312 -w451 -w473 -I../swig %s -DFL_EXPORT -DPYTHON -module fltk -c++ -python -shadow -modern -dirprot -o fltk_wrap.cpp ../swig/fltk.i "%add_incl
     if is_msys_mingw():
@@ -67,7 +67,7 @@ if __name__=='__main__':
         print cmd_line
         os.system(cmd_line)
 
-    print "Copy fltk.py"
+    #print "Copy fltk.py"
     if os.path.isdir("../fltk"):
         shutil.rmtree("../fltk");
     os.mkdir("../fltk");
